pub fn default_credential_builder(
) -> Box<dyn CredentialBuilderApi + Sync + Send>
Return a keyutils credential builder.

If features are set to make keyutils the default store, this will be automatically be called once before the first credential is created.