pub struct KeyutilsCredential {
    pub session: KeyRing,
    pub persistent: Option<KeyRing>,
    pub description: String,
}
Representation of a keyutils credential.

Since the CredentialBuilderApi::build method does not provide an initial secret, and it is impossible to have 0-length keys, this representation holds a linux_keyutils::KeyRing instead of a linux_keyutils::Key.

The added benefit of this approach is that any call to get_password before set_password is done will result in a proper error as the key does not exist until set_password is called.

Fields

session: KeyRing

Host session keyring

persistent: Option<KeyRing>

Host persistent keyring

description: String

Description of the key entry

Implementations

source

impl KeyutilsCredential

source

pub fn get_credential(&self) -> Result<KeyutilsCredential, Error>

Create a credential from the matching keyutils key.

This is basically a no-op, because keys don’t have extra attributes, but at least we make sure the underlying platform credential exists.

source

pub fn new_with_target( target: Option<&str>, service: &str, user: &str ) -> Result<KeyutilsCredential, Error>

Create the platform credential for a Keyutils entry.

An explicit target string is interpreted as the KeyRing to use for the entry. If none is provided, then we concatenate the user and service in the string keyring-rs:user@service.