Struct keyring::native::mock::MockData

source ·
pub struct MockData {
    pub password: Option<String>,
    pub error: Option<Error>,
}
The (in-memory) persisted data for a mock credential.

We keep a password, but unlike most keystores we also keep an intended error to return on the next call.

(Everything about this structure is public for transparency. Most keystore implementation hide their internals.)

Fields

password: Option<String>error: Option<Error>