Struct keyring::native::mock::MockCredential
source · pub struct MockCredential {
pub inner: Mutex<RefCell<MockData>>,
}Expand description
The concrete mock credential
Mocks use an internal mutability pattern since entries are read-only. The mutex is used to make sure these are Sync.
Fields
inner: Mutex<RefCell<MockData>>Implementations